@@ -211,7 +211,7 @@ class StatementRuleInformation(sequence_ordered(), ModelSQL, ModelView):
 
     def _match_range(self, origin, information):
         low = getattr(self, '%s_low' % self.key_type)
-        high = getattr(self, '%s_high' % self.key_type)
+        high = getattr(self, '%_high' % self.key_type)
         amount = information.get(self.key.name)
         if amount is None:
             return False
@@ -332,6 +332,8 @@ class StatementRuleLine(sequence_ordered(), ModelSQL, ModelView):
 
         if not account:
             return
+        if not party:
+            party = origin.party
         if account.party_required and not party:
             return
         if not account.party_required:
